@@ -11,18 +11,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import click
-
-from lean import __version__
+from lean.commands.lean import lean
 from lean.commands.backtest import backtest
 from lean.commands.build import build
 from lean.commands.cloud import cloud
 from lean.commands.config import config
 from lean.commands.create_project import create_project
+from lean.commands.delete_project import delete_project
 from lean.commands.data import data
 from lean.commands.init import init
 from lean.commands.library import library
-from lean.commands.live import live
+from lean.commands.live.live import live
 from lean.commands.login import login
 from lean.commands.logout import logout
 from lean.commands.logs import logs
@@ -31,30 +30,20 @@ from lean.commands.report import report
 from lean.commands.research import research
 from lean.commands.whoami import whoami
 
-
-@click.group()
-@click.version_option(__version__)
-def lean() -> None:
-    """The Lean CLI by QuantConnect."""
-    # This method is intentionally empty
-    # It is used as the command group for all `lean <command>` commands
-    pass
-
-
 lean.add_command(config)
 lean.add_command(cloud)
 lean.add_command(data)
 lean.add_command(library)
-
+lean.add_command(live)
 lean.add_command(login)
 lean.add_command(logout)
 lean.add_command(whoami)
 lean.add_command(init)
 lean.add_command(create_project)
+lean.add_command(delete_project)
 lean.add_command(backtest)
 lean.add_command(optimize)
 lean.add_command(research)
 lean.add_command(report)
-lean.add_command(live)
 lean.add_command(build)
 lean.add_command(logs)
