@@ -11,17 +11,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import click
+from click import group
 
 from lean.commands.cloud.backtest import backtest
-from lean.commands.cloud.live import live
+from lean.commands.cloud.live.live import live
 from lean.commands.cloud.optimize import optimize
 from lean.commands.cloud.pull import pull
 from lean.commands.cloud.push import push
 from lean.commands.cloud.status import status
 
 
-@click.group()
+@group()
 def cloud() -> None:
     """Interact with the QuantConnect cloud."""
     # This method is intentionally empty
