@@ -11,19 +11,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import shutil
-import subprocess
 from pathlib import Path
 
-import click
-from pkg_resources import Requirement
+from click import command, argument, option
 
 from lean.click import LeanCommand, PathParameter
 from lean.container import container
 from lean.models.errors import MoreInfoError
 
 
-def _remove_csharp(project_dir: Path, name: str, no_local: bool) -> None:
+def _remove_package_from_csharp_project(project_dir: Path, name: str, no_local: bool) -> None:
     """Removes a custom C# library from a C# project.
 
     Removes the library from the project's .csproj file,
@@ -33,13 +30,15 @@ def _remove_csharp(project_dir: Path, name: str, no_local: bool) -> None:
     :param name: the name of the library to remove
     :param no_local:
     """
-    logger = container.logger()
-    path_manager = container.path_manager()
+    from shutil import which
+    from subprocess import run
+    logger = container.logger
+    path_manager = container.path_manager
 
     csproj_file = next(p for p in project_dir.iterdir() if p.name.endswith(".csproj"))
     logger.info(f"Removing {name} from '{path_manager.get_relative_path(csproj_file)}'")
 
-    xml_manager = container.xml_manager()
+    xml_manager = container.xml_manager
     csproj_tree = xml_manager.parse(csproj_file.read_text(encoding="utf-8"))
 
     for package_reference in csproj_tree.findall(".//PackageReference"):
@@ -48,16 +47,16 @@ def _remove_csharp(project_dir: Path, name: str, no_local: bool) -> None:
 
     csproj_file.write_text(xml_manager.to_string(csproj_tree), encoding="utf-8")
 
-    if not no_local and shutil.which("dotnet") is not None:
+    if not no_local and which("dotnet") is not None:
         logger.info(f"Restoring packages in '{path_manager.get_relative_path(project_dir)}'")
 
-        process = subprocess.run(["dotnet", "restore", str(csproj_file)], cwd=project_dir)
+        process = run(["dotnet", "restore", str(csproj_file)], cwd=project_dir)
 
         if process.returncode != 0:
             raise RuntimeError("Something went wrong while restoring packages, see the logs above for more information")
 
 
-def _remove_python(project_dir: Path, name: str) -> None:
+def _remove_pypi_package_from_python_project(project_dir: Path, name: str) -> None:
     """Removes a custom Python library from a Python project.
 
     Removes the library from the project's requirements.txt file.
@@ -65,8 +64,10 @@ def _remove_python(project_dir: Path, name: str) -> None:
     :param project_dir: the path to the project directory
     :param name: the name of the library to remove
     """
-    logger = container.logger()
-    path_manager = container.path_manager()
+    from pkg_resources import Requirement
+
+    logger = container.logger
+    path_manager = container.path_manager
 
     requirements_file = project_dir / "requirements.txt"
     logger.info(f"Removing {name} from '{path_manager.get_relative_path(requirements_file)}'")
@@ -90,16 +91,17 @@ def _remove_python(project_dir: Path, name: str) -> None:
     requirements_file.write_text(new_content, encoding="utf-8")
 
 
-@click.command(cls=LeanCommand, requires_docker=True)
-@click.argument("project", type=PathParameter(exists=True, file_okay=False, dir_okay=True))
-@click.argument("name", type=str)
-@click.option("--no-local", is_flag=True, default=False, help="Skip making changes to your local environment")
+@command(cls=LeanCommand, requires_docker=True)
+@argument("project", type=PathParameter(exists=True, file_okay=False, dir_okay=True))
+@argument("name", type=str)
+@option("--no-local", is_flag=True, default=False, help="Skip making changes to your local environment")
 def remove(project: Path, name: str, no_local: bool) -> None:
     """Remove a custom library from a project.
 
     PROJECT must be the path to the project directory.
 
-    NAME must be the name of the NuGet package (for C# projects) or of the PyPI package (for Python projects) to remove.
+    NAME must be either the name of the NuGet package (for C# projects), the PyPI package (for Python projects),
+    or the path to the Lean CLI library to remove.
 
     Custom C# libraries are removed from the project's .csproj file,
     which is then restored if dotnet is on your PATH and the --no-local flag has not been given.
@@ -114,14 +116,22 @@ def remove(project: Path, name: str, no_local: bool) -> None:
     Python example usage:
     $ lean library remove "My Python Project" tensorflow
     """
-    project_config = container.project_config_manager().get_project_config(project)
+    project_config = container.project_config_manager.get_project_config(project)
     project_language = project_config.get("algorithm-language", None)
 
     if project_language is None:
         raise MoreInfoError(f"{project} is not a Lean CLI project",
-                            "https://www.lean.io/docs/lean-cli/projects/project-management#02-Create-Projects")
+                            "https://www.lean.io/docs/v2/lean-cli/projects/project-management#02-Create-Projects")
 
-    if project_language == "CSharp":
-        _remove_csharp(project, name, no_local)
+    library_manager = container.library_manager
+    library_dir = Path(name).expanduser().resolve()
+    if library_manager.is_lean_library(library_dir):
+        if project_language == "CSharp":
+            library_manager.remove_lean_library_from_csharp_project(project, library_dir, no_local)
+        else:
+            library_manager.remove_lean_library_from_python_project(project, library_dir)
     else:
-        _remove_python(project, name)
+        if project_language == "CSharp":
+            _remove_package_from_csharp_project(project, name, no_local)
+        else:
+            _remove_pypi_package_from_python_project(project, name)
