@@ -13,16 +13,17 @@
 
 from typing import Optional
 
-import click
+from click import command, option, prompt
 
 from lean.click import LeanCommand
 from lean.container import container
 from lean.models.errors import MoreInfoError
+from lean.components.api.api_client import APIClient
 
 
-@click.command(cls=LeanCommand)
-@click.option("--user-id", "-u", type=str, help="QuantConnect user id")
-@click.option("--api-token", "-t", type=str, help="QuantConnect API token")
+@command(cls=LeanCommand)
+@option("--user-id", "-u", type=str, help="QuantConnect user id")
+@option("--api-token", "-t", type=str, help="QuantConnect API token")
 def login(user_id: Optional[str], api_token: Optional[str]) -> None:
     """Log in with a QuantConnect account.
 
@@ -30,8 +31,8 @@ def login(user_id: Optional[str], api_token: Optional[str]) -> None:
 
     Credentials are stored in ~/.lean/credentials and are removed upon running `lean logout`.
     """
-    logger = container.logger()
-    credentials_storage = container.credentials_storage()
+    logger = container.logger
+    credentials_storage = container.credentials_storage
 
     if user_id is None or api_token is None:
         logger.info("Your user id and API token are needed to make authenticated requests to the QuantConnect API")
@@ -39,17 +40,17 @@ def login(user_id: Optional[str], api_token: Optional[str]) -> None:
         logger.info(f"Both will be saved in {credentials_storage.file}")
 
     if user_id is None:
-        user_id = click.prompt("User id")
+        user_id = prompt("User id")
 
     if api_token is None:
         api_token = logger.prompt_password("API token")
 
-    api_client = container.api_client(user_id=user_id, api_token=api_token)
-    if not api_client.is_authenticated():
-        raise MoreInfoError("Credentials are invalid",
-                            "https://www.lean.io/docs/lean-cli/initialization/authenticating-accounts#02-Log-In")
+    container.api_client.set_user_token(user_id=user_id, api_token=api_token)
+    if not container.api_client.is_authenticated():
+        raise MoreInfoError("Credentials are invalid. Please ensure your computer clock is correct, or try using another terminal, or enter API token manually instead of copy-pasting.",
+                            "https://www.lean.io/docs/v2/lean-cli")
 
-    cli_config_manager = container.cli_config_manager()
+    cli_config_manager = container.cli_config_manager
     cli_config_manager.user_id.set_value(user_id)
     cli_config_manager.api_token.set_value(api_token)
 
