@@ -11,9 +11,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import os
-from shutil import move
-from tempfile import NamedTemporaryFile
 from lean.components.api.api_client import *
 from lean.models.api import QCDataInformation
 from typing import List, Callable
@@ -42,6 +39,10 @@ class DataClient:
         :param local_filename: the final local path where the data file will be stored
         :param progress_callback: the download progress callback
         """
+        from tempfile import NamedTemporaryFile
+        from shutil import move
+        from os import path, makedirs
+
         data = self._api.post("data/read", {
             "format": "link",
             "filePath": relative_file_path,
@@ -72,8 +73,8 @@ class DataClient:
                 # if total size not available update progress at the end
                 progress_callback(1)
 
-            directory = os.path.dirname(local_filename)
-            os.makedirs(directory, exist_ok=True)
+            directory = path.dirname(local_filename)
+            makedirs(directory, exist_ok=True)
             move(temp_file_name, local_filename)
 
     def download_public_file(self, data_endpoint: str) -> bytes:
