@@ -323,7 +323,15 @@ class LeanRunner:
                                            read_only=True))
 
         # Assign the container a name and store it in the output directory's configuration
-        run_options["name"] = f"lean_cli_{str(uuid4()).replace('-', '')}"
+        if "container-name" in lean_config:
+            run_options["name"] = lean_config["container-name"]
+        else:
+            run_options["name"] = f"lean_cli_{str(uuid4()).replace('-', '')}"
+        
+        # set the hostname
+        if "hostname" in lean_config:
+            run_options["hostname"] = lean_config["hostname"]
+
         output_config = self._output_config_manager.get_output_config(output_dir)
         output_config.set("container", run_options["name"])
         if "backtest-name" in lean_config:
