@@ -13,13 +13,11 @@
 
 from typing import Optional
 
-import requests
-
 
 class RequestFailedError(Exception):
     """A RequestFailedError indicates that an HTTP request has failed."""
 
-    def __init__(self, response: requests.Response, message: Optional[str] = None) -> None:
+    def __init__(self, response, message: Optional[str] = None) -> None:
         """Creates a new RequestFailedError instance.
 
         :param response: the data of the failed response
@@ -54,4 +52,4 @@ class AuthenticationError(MoreInfoError):
     def __init__(self) -> None:
         """Creates a new AuthenticationError instance."""
         super().__init__("Invalid credentials, please log in using `lean login`",
-                         "https://www.lean.io/docs/lean-cli/initialization/authenticating-accounts#02-Log-In")
+                         "https://www.lean.io/docs/v2/lean-cli/initialization/authenticating-accounts#02-Log-In")
