@@ -14,8 +14,6 @@
 from enum import Enum
 from typing import Any, Dict, List, Type
 from lean.components.util.logger import Logger
-from lean.container import container
-from lean.models.logger import Option
 from lean.models.configuration import BrokerageEnvConfiguration, Configuration, InternalInputUserInput
 from copy import copy
 from abc import ABC
@@ -119,6 +117,9 @@ class JsonModule(ABC):
                             and self.check_if_config_passes_filters(config)]
         return required_configs
 
+    def get_persistent_save_properties(self, filters: List[Type[Configuration]] = []) -> List[str]:
+        return [config._id for config in self.get_required_configs(filters) if config._save_persistently_in_lean]
+
     def get_essential_properties(self) -> List[str]:
         return [config._id for config in self.get_essential_configs()]
 
